==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/usermanager/lang/ro/lang.php <==
<?php
/**
 * Romanian language file
 *
 * @author Sergiu Baltariu <s_baltariu@yahoo.com>
 * @author s_baltariu@yahoo.com
 */
$lang['menu']                  = 'Manager Utilizatori';
$lang['noauth']                = '(autentificarea utilizatorilor nu este disponibilă)';
$lang['nosupport']             = '(menegementul utilizatorilor nu e suportat)';
$lang['badauth']               = 'mecanism de autentificare invalid';
$lang['user_id']               = 'Utilizator';
$lang['user_pass']             = 'Parolă';
$lang['user_name']             = 'Nume Real';
$lang['user_mail']             = 'Email';
$lang['user_groups']           = 'Grupuri';
$lang['field']                 = 'Câmp';
$lang['value']                 = 'Valoare';
$lang['add']                   = 'Adaugă';
$lang['delete']                = 'Şterge';
$lang['delete_selected']       = 'Şterge selecţia';
$lang['edit']                  = 'Editează';
$lang['edit_prompt']           = 'Editează acest utilizator';
$lang['modify']                = 'Salvează Modificările';
$lang['search']                = 'Caută';
$lang['search_prompt']         = 'Se caută';
$lang['clear']                 = 'Resetează Filtrul de Căutare';
$lang['filter']                = 'Filtru';
$lang['summary']               = 'Afişarea utilizatorilor %1$d-%2$d din %3$d găsită. %4$d utilizatori în total.';
$lang['nonefound']             = 'Nici un utilizator nu a fost găsit. %d utilizatori în total.';
$lang['delete_ok']             = '%d utilizatori şterşi';
$lang['delete_fail']           = '%d eşuat la ştergere.';
$lang['update_ok']             = 'Utilizatorul a fost actualizat cu succes';
$lang['update_fail']           = 'Actualizarea utilizatorului a eşuat';
$lang['update_exists']         = 'Modificarea numelui de utilizator a eşuat. Numele de utilizator specificat (%s) există deja (orice altă modificare se va aplica)';
$lang['start']                 = 'început';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'urmator';
$lang['last']                  = 'sfârşit';
$lang['edit_usermissing']      = 'Utilizatorul selectat nu a fost găsit. E posibil ca numele de utilizator specificat să fi fost şters sau modificat în altă parte.';
$lang['user_notify']           = 'Notificare utilizator';
$lang['note_notify']           = 'Emailurile de notificare sunt trimise numai dacă utilizatorului îi este dată o nouă parolă.';
$lang['note_group']            = 'Noii utilizatori vor fi adăugaţi la grupul implicit (%s) dacă nu se specifică grupul.';
$lang['add_ok']                = 'Utilizator adăugat cu succes';
$lang['add_fail']              = 'Adăugarea utilizatorului a eşuat';
$lang['notify_ok']             = 'Emailul de notificare a fost trimis';
$lang['notify_fail']           = 'Emailul de notificare nu a putut fi trimis';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/usermanager/lang/ro/lang.php <==
<?php
/**
 * Romanian language file
 *
 * @author Sergiu Baltariu <s_baltariu@yahoo.com>
 * @author s_baltariu@yahoo.com
 * @author Emanuel-Emeric Andrasi <n30@mandrivausers.ro>
 */
$lang['menu']                  = 'Manager Utilizatori';
$lang['noauth']                = '(autentificarea utilizatorilor nu este disponibilă)';
$lang['nosupport']             = '(menegementul utilizatorilor nu e suportat)';
$lang['badauth']               = 'mecanism de autentificare invalid';
$lang['user_id']               = 'Utilizator';
$lang['user_pass']             = 'Parolă';
$lang['user_name']             = 'Nume Real';
$lang['user_mail']             = 'Email';
$lang['user_groups']           = 'Grupuri';
$lang['field']                 = 'Câmp';
$lang['value']                 = 'Valoare';
$lang['add']                   = 'Adaugă';
$lang['delete']                = 'Şterge';
$lang['delete_selected']       = 'Şterge selecţia';
$lang['edit']                  = 'Editează';
$lang['edit_prompt']           = 'Editează acest utilizator';
$lang['modify']                = 'Salvează Modificările';
$lang['search']                = 'Caută';
$lang['search_prompt']         = 'Se caută';
$lang['clear']                 = 'Resetează Filtrul de Căutare';
$lang['filter']                = 'Filtru';
$lang['summary']               = 'Afişarea utilizatorilor %1$d-%2$d din %3$d găsită. %4$d utilizatori în total.';
$lang['nonefound']             = 'Nici un utilizator nu a fost găsit. %d utilizatori în total.';
$lang['delete_ok']             = '%d utilizatori şterşi';
$lang['delete_fail']           = '%d eşuat la ştergere.';
$lang['update_ok']             = 'Utilizatorul a fost actualizat cu succes';
$lang['update_fail']           = 'Actualizarea utilizatorului a eşuat';
$lang['update_exists']         = 'Modificarea numelui de utilizator a eşuat. Numele de utilizator specificat (%s) există deja (orice altă modificare se va aplica)';
$lang['start']                 = 'început';
$lang['prev']                  = 'anterior';
$lang['next']                  = 'urmator';
$lang['last']                  = 'sfârşit';
$lang['edit_usermissing']      = 'Utilizatorul selectat nu a fost găsit. E posibil ca numele de utilizator specificat să fi fost şters sau modificat în altă parte.';
$lang['user_notify']           = 'Notificare utilizator';
$lang['note_notify']           = 'Emailurile de notificare sunt trimise numai dacă utilizatorului îi este dată o nouă parolă.';
$lang['note_group']            = 'Noii utilizatori vor fi adăugaţi la grupul implicit (%s) dacă nu se specifică grupul.';
$lang['note_pass']             = 'Parola va fi regenerată automat dacă câmpul este lăsat gol şi notificarea utilizatorului este activată.';
$lang['add_ok']                = 'Utilizator adăugat cu succes';
$lang['add_fail']              = 'Adăugarea utilizatorului a eşuat';
$lang['notify_ok']             = 'Emailul de notificare a fost trimis';
$lang['notify_fail']           = 'Emailul de notificare nu a putut fi trimis';
